=============================================
Biorefineries: Biorefinery Models in BioSTEAM
=============================================

.. image:: http://img.shields.io/pypi/v/biorefineries.svg?style=flat
   :target: https://pypi.python.org/pypi/biorefineries
   :alt: Version_status
.. image:: http://img.shields.io/badge/license-MIT-blue.svg?style=flat
   :target: https://github.com/yoelcortes/Bioindustrial-Park/biorefineries/blob/master/LICENSE.txt
   :alt: license


.. contents::

What is Biorefineries?
----------------------

Biorefineries serves as a standard package for complete biorefinery models in BioSTEAM.

Installation
------------

Get the latest version of biorefineries from
https://pypi.python.org/pypi/biorefineries/

If you have an installation of Python with pip, simple install it with:

    $ pip install biorefineries

To get the git version, run:

    $ git clone git:github.com/yoelcortes/Bioindustrial-Park/tree/master/biorefineries/BioSTEAM 2.x.x/biorefineries

Documentation
-------------

Documentation for BioSTEAM's premier biorefinery models are available on the web:

    http://biosteam.readthedocs.io/

Bug reports
-----------

To report bugs, please use the biorefineries's Bug Tracker at:

    git://github.com/yoelcortes/Bioindustrial-Park

License information
-------------------

See ``LICENSE.txt`` for information on the terms & conditions for usage
of this software, and a DISCLAIMER OF ALL WARRANTIES.


